<div id="widgetvisualization-{{widget.pk}}" rel="{{widget.pk}}" class="widgetvisualizationdialog" title="{{widget.name}} visualization">
<div style="width:400px;white-space:pre-wrap;font-family:monospace;">
<pre style="width:400px !important;white-space:pre">
<p style="width:160px; float:left"><b>Precision:<b></p><p style="width:100px; float:left">{{result.precision|floatformat:"6"}}</p>
<p style="width:160px; float:left"><b>Recall:<b></p><p style="width:100px; float:left">{{result.recall|floatformat:"6"}}</p>
<p style="width:160px; float:left"><b>F1 score:<b></p><p style="width:100px; float:left">{{result.F1score|floatformat:"6"}}</p>
</pre>
</div>
</div>